aboutsummaryrefslogtreecommitdiff
path: root/backends/keymapper/keymap.h
diff options
context:
space:
mode:
authorTarek Soliman2012-02-24 13:23:55 -0600
committerTarek Soliman2012-02-27 13:00:56 -0600
commit6afac4e01eba5c297e99597dd2cb17c2e4732a7e (patch)
treeda3a7473c70f529a7cc399975349607d412eb713 /backends/keymapper/keymap.h
parentb0f961924a856b71ebffdb834db122145c4c10e5 (diff)
downloadscummvm-rg350-6afac4e01eba5c297e99597dd2cb17c2e4732a7e.tar.gz
scummvm-rg350-6afac4e01eba5c297e99597dd2cb17c2e4732a7e.tar.bz2
scummvm-rg350-6afac4e01eba5c297e99597dd2cb17c2e4732a7e.zip
KEYMAPPER: Rename HardwareKey to HardwareInput
Diffstat (limited to 'backends/keymapper/keymap.h')
-rw-r--r--backends/keymapper/keymap.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/backends/keymapper/keymap.h b/backends/keymapper/keymap.h
index 2e9f08533e..4c3e89700f 100644
--- a/backends/keymapper/keymap.h
+++ b/backends/keymapper/keymap.h
@@ -36,8 +36,8 @@
namespace Common {
-struct HardwareKey;
-class HardwareKeySet;
+struct HardwareInput;
+class HardwareInputSet;
/**
* Hash function for KeyState
@@ -80,9 +80,9 @@ public:
/**
* Load this keymap's mappings from the config manager.
* @param hwKeys the set to retrieve hardware key pointers from
*/
- void loadMappings(const HardwareKeySet *hwKeys);
+ void loadMappings(const HardwareInputSet *hwInputs);
/**
* Save this keymap's mappings to the config manager
@@ -93,9 +93,9 @@ public:
/**
* Returns true if all UserAction's in Keymap are mapped, or,
* all HardwareKey's from the given set have been used up.
*/
- bool isComplete(const HardwareKeySet *hwKeys);
+ bool isComplete(const HardwareInputSet *hwInputs);
const String& getName() { return _name; }
@@ -110,15 +110,15 @@ private:
void addAction(Action *action);
/**
* Registers a HardwareKey to the given Action
* @param action Action in this Keymap
* @param key pointer to HardwareKey to map
* @see Action::mapKey
*/
- void registerMapping(Action *action, const HardwareKey *key);
+ void registerMapping(Action *action, const HardwareInput *input);
/**
* Unregisters a HardwareKey from the given Action (if one is mapped)
* @param action Action in this Keymap
* @see Action::mapKey
*/
@@ -80,9 +80,9 @@ public:
/**
* Load this keymap's mappings from the config manager.
- * @param hwKeys the set to retrieve hardware key pointers from
+ * @param hwInputs the set to retrieve hardware input pointers from
*/
@@ -93,9 +93,9 @@ public:
/**
* Returns true if all UserAction's in Keymap are mapped, or,
- * all HardwareKey's from the given set have been used up.
+ * all HardwareInputs from the given set have been used up.
*/
@@ -110,15 +110,15 @@ private:
void addAction(Action *action);
/**
- * Registers a HardwareKey to the given Action
+ * Registers a HardwareInput to the given Action
* @param action Action in this Keymap
@@ -110,15 +110,15 @@ private:
* @param action Action in this Keymap
- * @param key pointer to HardwareKey to map
+ * @param key pointer to HardwareInput to map
* @see Action::mapKey
*/
@@ -110,15 +110,15 @@ private:
/**
- * Unregisters a HardwareKey from the given Action (if one is mapped)
+ * Unregisters a HardwareInput from the given Action (if one is mapped)
* @param action Action in this Keymap
* @see Action::mapKey